<?php
/**
 * Plugin Name: Connectix
 * Plugin URI: https://connectix.bg/integrations.html?d=plugin-wordpress-5-x
 * Description: Marketing messaging
 * Version: 5.0.27
 * Author: Connectix ood
 * Author URI: https://connectix.bg/
 * Text Domain: connectix
 * Domain Path: /languages/
 * Requires at least: 5.3
 * Requires PHP: 7.0
 *
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 */

use WooCommerce\Connectix\Api;
use WooCommerce\Connectix\Callback;
use WooCommerce\Connectix\Events;
use WooCommerce\Connectix\Installer;
use WooCommerce\Connectix\SettingsPage;

defined( 'ABSPATH') || exit;

require_once __DIR__.'/vendor/autoload.php';

(new Installer(__FILE__))->init();

add_action('plugins_loaded', function() {
    load_plugin_textdomain('connectix', false, basename(dirname( __FILE__ )).'/languages/');
});

add_action('init', function() {
    if (is_admin()) {
        // Setup menu
        $assets_url = plugin_dir_url(__FILE__);
        (new SettingsPage($assets_url))->init();
    }

    add_action('rest_api_init', function () {
        (new Api())->add_routes();
    });
});

if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    add_action('init', function() {
        if (is_admin()) {
            wp_register_style('connectix_admin', plugin_dir_url(__FILE__) . 'assets/css/admin.css');
            wp_enqueue_style('connectix_admin');
        }

        (new Events())->init();

        // Setup REST API
        add_action('rest_api_init', function () {
            (new Callback())->add_routes();
        });

        // Setup meta boxes
        add_action('add_meta_boxes', function () {
            require_once 'includes/admin/meta-boxes/class-connetix-meta-box-order-messages.php';
            add_meta_box('connectix-order-messages', __( 'title', 'connectix' ), 'Connectix_Meta_Box_Order_Messages::output');
        });
    });
}
