<?php

defined('ABSPATH') || exit;

/**
 * Class Connectix_Meta_Box_Order_Messages
 */
class Connectix_Meta_Box_Order_Messages {

    /**
     * Output the metabox.
     *
     * @param WP_Post $post
     */
	public static function output(WP_Post $post)
    {
        global $wpdb;

        $records = $wpdb->get_results('SELECT
                    m.*,
                    mi.id as mi_id,
                    mi.message_id as mi_message_id,
                    mi.type as mi_type,
                    mi.text as mi_text,
                    mi.media_url as mi_media_url,
                    mi.media_name as mi_media_name,
                    mi.sent_at as mi_sent_at
                FROM '.$wpdb->prefix.'connectix_messages m
                LEFT JOIN '.$wpdb->prefix.'connectix_message_inbounds mi ON m.id = mi.message_id
                WHERE
                    m.status <> \'pending\'
                AND
                    m.order_id = '.(int)$post->ID.'
                ORDER BY m.id ASC', ARRAY_A);

        $viberLink = null;
        $messages = [];
        foreach ($records as $record) {
            if (!$viberLink && $record['channel'] === 'viber') {
                $order = wc_get_order($post->ID);
                $phone = $order->get_billing_phone();

                if ('0' === substr($phone, 0, 1)) {
                    $calling_code = WC()->countries->get_country_calling_code($order->get_billing_country());
                    $calling_code = is_array( $calling_code ) ? $calling_code[0] : $calling_code;
                    $phone = $calling_code.ltrim($phone, '0');
                }
                $viberLink = 'viber://chat?number='.$phone;
            }

            if (!isset($messages[$record['id']])) {
                $messages[$record['id']] = [
                    "id" => $record['id'],
                    "order_id" => $record['order_id'],
                    "fallback_id" => $record['fallback_id'],
                    "type" => $record['type'],
                    "text" => $record['text'],
                    "channel" => $record['channel'],
                    "status" => 'message_status_'.$record['status'],
                    "created_at" => $record['created_at'],
                    "provider_id" => $record['provider_id'],
                    "inbounds" => [],
                ];
            }

            if (!empty($record['mi_id'])) {
                $messages[$record['id']]['inbounds'][] = [
                    'id' => $record['mi_id'],
                    'type' => $record['mi_type'],
                    'text' => $record['mi_text'],
                    'media_url' => $record['mi_media_url'],
                    'media_name' => $record['mi_media_name'],
                    'sent_at' => $record['mi_sent_at'],
                ];
            }
        }
		?>
		<div class="wc-metaboxes-wrapper">
			<div class="wc-metaboxes">
                <?php include __DIR__ . '/views/html-order-messages.php'; ?>
			</div>

            <?php
            if ($viberLink) {
                ?>
                <div class="toolbar">
                    <p class="buttons">
                        <a href="<?php echo $viberLink; ?>" class="button button-primary">
                            <?php echo __('open_viber', 'connectix')?>
                        </a>
                    </p>
                    <div class="clear"></div>
                </div>
                <?php
            }
            ?>
		</div>
		<?php
	}
}
