<?php

namespace WooCommerce\Connectix;

defined('ABSPATH') || exit;

/**
 * Class Installer
 * @package WooCommerce\Connectix
 */
class Installer
{
    /**
     * @var string
     */
    private $file;

    /**
     * Installer constructor.
     * @param string $file
     */
    public function __construct(string $file)
    {
        $this->file = $file;
    }

    public function init()
    {
        register_activation_hook($this->file, [$this, 'on_activation']);
        register_deactivation_hook($this->file, [$this, 'on_deactivation']);
    }

    public function on_activation()
    {
        global $wpdb;

        $collate = '';
        if ($wpdb->has_cap('collation')) {
            $collate = $wpdb->get_charset_collate();
        }

        Settings::set_defaults();

        $version = Settings::get_setting('db_version');

        include_once(dirname(__FILE__).'/../sql/install.php');
        $queries = [];
        $queries[] = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}connectix_message_inbounds (id INT AUTO_INCREMENT NOT NULL, message_id INT DEFAULT NULL, text LONGTEXT NOT NULL, sent_at DATETIME DEFAULT NULL, INDEX IDX_CEBA6A1C537A1329 (message_id), PRIMARY KEY(id)) $collate;";
        $queries[] = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}connectix_messages (id INT AUTO_INCREMENT NOT NULL, order_id INT NOT NULL, text VARCHAR(1200) NOT NULL, status VARCHAR(255) NOT NULL, channel VARCHAR(10) DEFAULT NULL, price NUMERIC(10, 4) NOT NULL, provider_id VARCHAR(64) DEFAULT NULL, fallback_id VARCHAR(64) DEFAULT NULL, created_at DATETIME DEFAULT NULL, type VARCHAR(255) DEFAULT NULL, delivery_type VARCHAR(6) NOT NULL, PRIMARY KEY(id)) $collate;";
        $queries[] = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}connectix_rules (id INT AUTO_INCREMENT NOT NULL, fallback TINYINT(1) NOT NULL, type VARCHAR(25) NOT NULL, order_status VARCHAR(25) DEFAULT NULL, delivery_type VARCHAR(6) DEFAULT NULL, enabled TINYINT(1) NOT NULL, days_not_picked_up INT DEFAULT NULL, PRIMARY KEY(id)) $collate;";
        $queries[] = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}connectix_rules_templates (id INT AUTO_INCREMENT NOT NULL, template_id INT NOT NULL, rule_id INT NOT NULL, position INT NOT NULL, INDEX IDX_37FB6BF5DA0FB8 (template_id), INDEX IDX_37FB6BF744E0351 (rule_id), PRIMARY KEY(id)) $collate;";
        $queries[] = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}connectix_templates (id INT AUTO_INCREMENT NOT NULL, media VARCHAR(255) DEFAULT NULL, layout VARCHAR(25) NOT NULL, name VARCHAR(255) NOT NULL, channel VARCHAR(10) NOT NULL, text LONGTEXT NOT NULL, button_label VARCHAR(255) DEFAULT NULL, button_url VARCHAR(255) DEFAULT NULL, status VARCHAR(255) NOT NULL, provider_id CHAR(36) NOT NULL COMMENT '(DC2Type:uuid)', UNIQUE INDEX UNIQ_FAB48C01A53A8AA (provider_id), PRIMARY KEY(id)) $collate;";
        $queries[] = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}connectix_tracking (id INT AUTO_INCREMENT NOT NULL, order_id INT NOT NULL, tracking_number VARCHAR(32) NOT NULL, PRIMARY KEY(id)) $collate;";
        $queries[] = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}connectix_order_token (id INT AUTO_INCREMENT NOT NULL, order_id INT NOT NULL, token VARCHAR(32) NOT NULL, status VARCHAR(10) DEFAULT NULL, created_at DATETIME NOT NULL, updated_at DATETIME NOT NULL, used TINYINT(1) NOT NULL, PRIMARY KEY(id)) $collate;";

        $table = $wpdb->get_row("show create table `{$wpdb->prefix}connectix_message_inbounds`;", ARRAY_A);
        if ($table && false === strpos($table['Create Table'], 'FK_CEBA6A1C537A13290')) {
            $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_message_inbounds ADD CONSTRAINT FK_CEBA6A1C537A13290 FOREIGN KEY IF NOT EXISTS (message_id) REFERENCES {$wpdb->prefix}connectix_messages (id) ON DELETE CASCADE;";
        }
        if ($table && false === strpos($table['Create Table'], 'type')) {
            $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_message_inbounds ADD type VARCHAR(10) NOT NULL;";
            $queries[] = "UPDATE {$wpdb->prefix}connectix_message_inbounds SET type = 'text';";
        }
        if ($table && false === strpos($table['Create Table'], 'media_url')) {
            $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_message_inbounds ADD media_url VARCHAR(255) DEFAULT NULL;";
        }
        if ($table && false === strpos($table['Create Table'], 'media_name')) {
            $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_message_inbounds ADD media_name VARCHAR(255) DEFAULT NULL;";
        }

        $table = $wpdb->get_row("show create table `{$wpdb->prefix}connectix_rules_templates`;", ARRAY_A);
        if ($table && false === strpos($table['Create Table'], 'FK_37FB6BF5DA0FB80')) {
            $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_rules_templates ADD CONSTRAINT FK_37FB6BF5DA0FB80 FOREIGN KEY IF NOT EXISTS (template_id) REFERENCES {$wpdb->prefix}connectix_templates (id) ON DELETE CASCADE;";
        }

        $table = $wpdb->get_row("show create table `{$wpdb->prefix}connectix_rules_templates`;", ARRAY_A);
        if ($table && false === strpos($table['Create Table'], 'FK_37FB6BF744E03510')) {
            $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_rules_templates ADD CONSTRAINT FK_37FB6BF744E03510 FOREIGN KEY IF NOT EXISTS (rule_id) REFERENCES {$wpdb->prefix}connectix_rules (id) ON DELETE CASCADE;";
        }

        foreach ($queries as $query) {
            $wpdb->query($query);
        }

        Settings::set_defaults();
    }

    public function on_deactivation()
    {
        Settings::delete_settings();
    }

    public static function drop_tables()
    {
        global $wpdb;

        $queries = [];
        $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_message_inbounds DROP FOREIGN KEY FK_CEBA6A1C537A13290;";
        $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_rules_templates DROP FOREIGN KEY FK_37FB6BF744E03510;";
        $queries[] = "ALTER TABLE {$wpdb->prefix}connectix_rules_templates DROP FOREIGN KEY FK_37FB6BF5DA0FB80;";
        $queries[] = "DROP TABLE {$wpdb->prefix}connectix_message_inbounds;";
        $queries[] = "DROP TABLE {$wpdb->prefix}connectix_messages;";
        $queries[] = "DROP TABLE {$wpdb->prefix}connectix_rules;";
        $queries[] = "DROP TABLE {$wpdb->prefix}connectix_rules_templates;";
        $queries[] = "DROP TABLE {$wpdb->prefix}connectix_templates;";
        $queries[] = "DROP TABLE {$wpdb->prefix}connectix_tracking;";
        $queries[] = "DROP TABLE {$wpdb->prefix}connectix_order_token;";

        foreach ($queries as $query) {
            $wpdb->query($query);
        }
    }
}
