<?php

namespace WooCommerce\Connectix;

defined('ABSPATH') || exit;

/**
 * Class Settings
 * @package WooCommerce\Connectix
 */
class Settings
{
    /**
     * Option key to save settings
     *
     * @var string
     */
    protected static $option_key = '_connectix_settings';

    /**
     * Default settings
     *
     * @var array
     */
    protected static $defaults = [
        'enabled' => true,
        'token' => null,
        'system' => 'sandbox',
        'secret' => null,
        'addContacts' => true,
        'trackDelivery' => true,
        'deliveredStatus' => null,
        'integrationToken' => null,
        'sandboxUrl' => null,
        'confirmOrder' => false,
        'confirmedOrderStatus' => null,
        'confirmedOrderUrl' => null,
        'cancelOrder' => false,
        'canceledOrderStatus' => null,
        'canceledOrderUrl' => null,
        'confirmationUrlsValidity' => null,
        'confirmationUrlsExpiredUrl' => null,
        'hookCallback' => null,
        'hookInbound' => null,
        'hookTemplate' => null,
        'hookTracking' => null,
        'db_version' => null,
    ];

    /**
     * Initial store the defaults
     */
    public static function set_defaults()
    {
        $defaults = self::$defaults;
        $defaults['secret'] = md5(uniqid((string)mt_rand(), true));

        update_option(self::$option_key, $defaults);
    }

    /**
     * Get saved settings
     *
     * @return array
     */
    public static function get_settings(): array
    {
        $defaults = self::$defaults;
        $saved = get_option(self::$option_key, []);
        if (!is_array($saved) || empty($saved)) {
            $defaults['secret'] = md5(uniqid((string)mt_rand(), true));
            return $defaults;
        }

        return wp_parse_args($saved, $defaults);
    }

    /**
     * Get saved setting
     *
     * @param string $name
     * @return mixed
     */
    public static function get_setting(string $name)
    {
        $settings = self::get_settings();

        return $settings[$name] ?? null;
    }

    /**
     * Save settings
     *
     * Array keys must be whitelisted (IE must be keys of self::$defaults
     *
     * @param array $settings
     */
    public static function save_settings(array $settings)
    {
        // remove any non-allowed indexes before save
        foreach ($settings as $setting => $value) {
            if (!array_key_exists($setting, self::$defaults)) {
                unset($settings[$setting]);
            }
        }

        $saved = get_option(self::$option_key, []);
        foreach ($saved as $setting => $value) {
            if (!array_key_exists($setting, self::$defaults)) {
                unset($saved[$setting]);
            }
        }
        update_option(self::$option_key, wp_parse_args($settings, $saved));
    }

    /**
     * Deletes settings
     */
    public static function delete_settings()
    {
        delete_option(self::$option_key);
    }
}
