<?php

namespace WooCommerce\Connectix;

defined('ABSPATH') || exit;

/**
 * Class SettingsPage
 * @package WooCommerce\Connectix
 */
class SettingsPage
{
    /**
     * Menu slug
     *
     * @var string
     */
    protected $slug = 'connectix-settings';

    /**
     * URL for assets
     *
     * @var string
     */
    protected $assets_url;

    /**
     * SettingsPage constructor.
     * @param $assets_url
     */
    public function __construct($assets_url)
    {
        $this->assets_url = $assets_url;
    }

    public function init()
    {
        add_action('admin_menu', [$this, 'add_page']);
    }

    /**
     * Add CF Popup submenu page
     *
     * @since 0.0.3
     *
     * @uses "admin_menu"
     */
    public function add_page()
    {
        add_menu_page(
            __('settings_title', 'connectix'),
            __('Connectix', 'connectix'),
            'manage_options',
            $this->slug,
            [$this, 'render_settings'],
            '',
            58 // Position right after WooCommerce menus
        );
    }

    /**
     * Enqueue CSS and JS for page
     */
    public function enqueue_assets()
    {
        $manifest = plugin_dir_path(__FILE__).'../ui/asset-manifest.json';
        if (file_exists($manifest) && $manifestContent = file_get_contents($manifest)) {
            $json = json_decode($manifestContent, true);
            foreach ($json['entrypoints'] as $entrypoint) {
                $name = 'connectix_'.$entrypoint;
                if (false !== strpos($entrypoint, '.js')) {
                    wp_register_script($name, $this->assets_url . 'ui/'.$entrypoint, [], false, true);
                    wp_enqueue_script($name);

                    if (false !== strpos($entrypoint, '/main')) {
                        wp_localize_script($name, 'ctxConfig', [
                            'controllerUrl' => esc_url_raw(rest_url('connectix-api/settings')),
                            'headers' => [
                                'X-WP-Nonce' => wp_create_nonce('wp_rest'),
                            ],
                            'translations' => [
                            'ask' => [
                                'title' => __('ask_title', 'connectix'),
                                'confirm' => __('ask_button_confirm', 'connectix'),
                                'cancel' => __('ask_button_cancel', 'connectix'),
                            ],
                            'settings' => [
                                'title' => __('settings_title', 'connectix'),
                                'label' => [
                                    'enabled' => __('settings_label_enabled', 'connectix'),
                                    'token' => __('settings_label_token', 'connectix'),
                                    'save' => __('settings_label_save', 'connectix'),
                                    'addContacts' => __('settings_add_contacts', 'connectix'),
                                    'trackDelivery' => __('settings_track_delivery', 'connectix'),
                                    'deliveredStatus' => __('settings_delivered_status', 'connectix'),
                                    'deliveredStatus_help' => __('settings_delivered_status_help', 'connectix'),
                                    'system' => __('settings_label_system', 'connectix'),
                                    'system_sandbox' => __('settings_label_system_sandbox', 'connectix'),
                                    'system_live' => __('settings_label_system_live', 'connectix'),
                                    'sandboxUrl' => __('settings_label_sandboxUrl', 'connectix'),
                                    'sandboxUrl_help' => __('settings_label_sandboxUrl_help', 'connectix'),
                                    'confirmOrder' => __('settings_label_confirmOrder', 'connectix'),
                                    'confirmedOrderStatus' => __('settings_label_confirmedOrderStatus', 'connectix'),
                                    'confirmedOrderStatus_help' => __('settings_label_confirmedOrderStatus_help', 'connectix'),
                                    'confirmedOrderUrl' => __('settings_label_confirmedOrderUrl', 'connectix'),
                                    'confirmedOrderUrl_help' => __('settings_label_confirmedOrderUrl_help', 'connectix'),
                                    'cancelOrder' => __('settings_label_cancelOrder', 'connectix'),
                                    'canceledOrderStatus' => __('settings_label_canceledOrderStatus', 'connectix'),
                                    'canceledOrderStatus_help' => __('settings_label_canceledOrderStatus_help', 'connectix'),
                                    'canceledOrderUrl' => __('settings_label_canceledOrderUrl', 'connectix'),
                                    'canceledOrderUrl_help' => __('settings_label_canceledOrderUrl_help', 'connectix'),
                                    'confirmationUrlsValidity' => __('settings_label_confirmationUrlsValidity', 'connectix'),
                                    'confirmationUrlsValidity_help' => __('settings_label_confirmationUrlsValidity_help', 'connectix'),
                                    'confirmationUrlsExpiredUrl' => __('settings_label_confirmationUrlsExpiredUrl', 'connectix'),
                                    'confirmationUrlsExpiredUrl_help' => __('settings_label_confirmationUrlsExpiredUrl_help', 'connectix'),
                                ],
                                'token_placeholder' => __('settings_token_placeholder', 'connectix'),
                                'token_already_entered' => __('settings_token_already_entered', 'connectix'),
                                'sandboxUrl_placeholder' => __('settings_token_placeholder', 'connectix'),
                            ],
                            'templates' => [
                                'button' => __('templates_button', 'connectix'),
                                'button_help' => __('templates_button_help', 'connectix'),
                                'no_templates' => __('templates_no_templates', 'connectix'),
                                'status' => [
                                    'pending' => __('templates_status_pending', 'connectix'),
                                    'rejected' => __('templates_status_rejected', 'connectix'),
                                    'waiting_information' => __('templates_status_waiting_information', 'connectix'),
                                    'approved' => __('templates_status_approved', 'connectix'),
                                ],
                            ],
                            'rules' => [
                                'adding_title' => __('rules_adding_title', 'connectix'),
                                'editing_title' => __('rules_editing_title', 'connectix'),
                                'button' => __('rules_button', 'connectix'),
                                'no_rules' => __('rules_no_rules', 'connectix'),
                                'label' => [
                                    'enabled' => __('rules_label_enabled', 'connectix'),
                                    'not_enabled' => __('rules_label_not_enabled', 'connectix'),
                                    'fallback' => __('rules_label_fallback', 'connectix'),
                                    'fallback_help' => str_replace('[1]', '<br />', __('rules_label_fallback_help', 'connectix')),
                                    'type' => __('rules_label_type', 'connectix'),
                                    'type_help' => __('rules_label_type_help', 'connectix'),
                                    'delivery_type' => __('rules_label_delivery_type', 'connectix'),
                                    'order_status' => __('rules_label_order_status', 'connectix'),
                                    'add_template' => __('rules_label_add_template', 'connectix'),
                                    'add_another_template' => __('rules_label_add_another_template', 'connectix'),
                                    'days_not_picked_up' => __('rules_label_days_not_picked_up', 'connectix'),
                                    'days_not_picked_up_help_example_header' => __('rules_label_days_not_picked_up_help_example_header', 'connectix'),
                                    'days_not_picked_up_help_example' => __('rules_label_days_not_picked_up_help_example', 'connectix'),
                                    'days_not_picked_up_help_note_header' => __('rules_label_days_not_picked_up_help_note_header', 'connectix'),
                                    'days_not_picked_up_help_note' => __('rules_label_days_not_picked_up_help_note', 'connectix'),
                                    'cancel' => __('rules_label_cancel', 'connectix'),
                                    'save' => __('rules_label_save', 'connectix'),
                                ],
                                'days' => __('rules_days', 'connectix'),
                                'order_status_placeholder' => __('rules_order_status_placeholder', 'connectix'),
                                'templates_placeholder' => __('rules_templates_placeholder', 'connectix'),
                                'delivery_type_placeholder' => __('rules_delivery_type_placeholder', 'connectix'),
                                'delivery_type' => [
                                    'door' => __('rules_delivery_type_door', 'connectix'),
                                    'office' => __('rules_delivery_type_office', 'connectix'),
                                ],
                                'channel' => __('rules_channel', 'connectix'),
                                'template' => __('rules_template', 'connectix'),
                                'actions' => __('rules_actions', 'connectix'),
                                'type' => [
                                    'new_order' => __('rules_type_new_order', 'connectix'),
                                    'change_order_status' => __('rules_type_change_order_status', 'connectix'),
                                    'ready_for_delivery' => __('rules_type_ready_for_delivery', 'connectix'),
                                    'not_picked_up' => __('rules_type_change_not_picked_up', 'connectix'),
                                ],
                                'type_placeholder' => __('rules_type_placeholder', 'connectix'),
                                'status' => [
                                    'pending' => __('rules_status_pending', 'connectix'),
                                    'rejected' => __('rules_status_rejected', 'connectix'),
                                    'waiting_information' => __('rules_status_waiting_information', 'connectix'),
                                    'approved' => __('rules_status_approved', 'connectix'),
                                ],
                            ],
                            ],
                        ]);
                    }
                } else {
                    wp_register_style($name, $this->assets_url . 'ui/'.$entrypoint);
                    wp_enqueue_style($name);
                }
            }
        }
    }

    /**
     * Render plugin admin page
     */
    public function render_settings()
    {
        $this->enqueue_assets();
        echo '<div id="connectix-ui"></div>';
    }
}
