<?php

namespace Connectix\Components;

use Connectix\Exception\RequiredValueException;

/**
 * Class Contact
 * @package Connectix\Components
 */
final class Contact extends BaseComponent
{
	/**
	 * @var bool
	 */
	protected $addGroupIfMissing = true;

	/**
	 * @var string|null
	 */
	protected $firstName;

	/**
	 * @var string|null
	 */
	protected $lastName;

	/**
	 * @var string[]
	 */
	protected $groups = [];

	/**
	 * @inheritDoc
	 */
	public function getRequiredFields(): array
	{
		return ['firstName'];
	}

	/**
	 * @return null[]|string[]
	 * @throws RequiredValueException
	 */
	public function toArray(): array
	{
		$this->validate();

		$params = [
			'firstName' => $this->getFirstName(),
		];

		if (null !== $this->getLastName()) {
			$params['lastName'] = $this->getLastName();
		}

		if (!empty($this->getGroups())) {
			$params['groups'] = $this->getGroups();
		}

		$params['addGroupIfMissing'] = $this->isAddGroupIfMissing();

		return $params;
	}

	/**
	 * @inheritDoc
	 */
	public function toJson(): string
	{
		if ($data = json_encode($this->toArray())) {
			return $data;
		}

		return '';
	}

	/**
	 * @return bool
	 */
	public function isAddGroupIfMissing(): bool
	{
		return $this->addGroupIfMissing;
	}

	/**
	 * @param bool $addGroupIfMissing
	 * @return Contact
	 */
	public function setAddGroupIfMissing(bool $addGroupIfMissing): Contact
	{
		$this->addGroupIfMissing = $addGroupIfMissing;

		return $this;
	}

	/**
	 * @return string|null
	 */
	public function getFirstName()
	{
		return $this->firstName;
	}

	/**
	 * @param string|null $firstName
	 * @return Contact
	 */
	public function setFirstName(string $firstName): Contact
	{
		$this->firstName = $firstName;

		return $this;
	}

	/**
	 * @return string|null
	 */
	public function getLastName()
	{
		return $this->lastName;
	}

	/**
	 * @param string|null $lastName
	 * @return Contact
	 */
	public function setLastName(string $lastName): Contact
	{
		$this->lastName = $lastName;

		return $this;
	}

	/**
	 * @return string[]
	 */
	public function getGroups(): array
	{
		return $this->groups;
	}

	/**
	 * @param string[] $groups
	 * @return Contact
	 */
	public function setGroups(array $groups): Contact
	{
		$this->groups = $groups;

		return $this;
	}

	/**
	 * @return string
	 */
	public function getName(): string
	{
		$names = [$this->getFirstName()];
		if ($this->getLastName()) {
			$names[] = $this->getLastName();
		}

		return join(' ', $names);
	}
}
